RomManager

Struct RomManager 

pub struct RomManager {
    pub roms: Vec<RomMeta>,
    /* private fields */
}

Fields

roms: Vec<RomMeta>

Implementations

Source

impl RomManager

pub fn new(base: PathBuf) -> RomManager

pub fn load(&mut self, definitions: &Definitions) -> Result<()>

Loads rom metadata

pub fn save_meta(&self) -> Result<()>

Saves all metadata

pub fn search(&self, id: &str) -> Option<&RomMeta>

Searches for a ROM meta with the specified id

pub fn new_rom( &mut self, name: String, id: String, platform: Rc<Main>, model: Rc<Model>, data: Vec<u8>, ) -> Rc<Rom>

Creates a new ROM, adds it to the database. It will NOT be saved. Note: save_meta() should be called as the ROM metadata will not be saved by this function. Rom::save() should also be called to save the ROM data. If another ROM with the same id already exists, undefined behavior will occur.

pub fn load_rom(&self, meta: &RomMeta) -> Result<Rc<Rom>>

Loads a ROM or retrieves it from the cache.