pub struct RomManager {
pub roms: Vec<RomMeta>,
/* private fields */
}Fields
roms: Vec<RomMeta>Implementations
Sourceimpl RomManager
impl RomManager
pub fn new(base: PathBuf) -> RomManager
Sourcepub fn load(&mut self, definitions: &Definitions) -> Result<()>
pub fn load(&mut self, definitions: &Definitions) -> Result<()>
Loads rom metadata
Sourcepub fn search(&self, id: &str) -> Option<&RomMeta>
pub fn search(&self, id: &str) -> Option<&RomMeta>
Searches for a ROM meta with the specified id
Sourcepub fn new_rom(
&mut self,
name: String,
id: String,
platform: Rc<Main>,
model: Rc<Model>,
data: Vec<u8>,
) -> Rc<Rom>
pub fn new_rom( &mut self, name: String, id: String, platform: Rc<Main>, model: Rc<Model>, data: Vec<u8>, ) -> Rc<Rom>
Creates a new ROM, adds it to the database. It will NOT be saved.
Note: save_meta() should be called as the ROM metadata will not be saved by this function.
Rom::save() should also be called to save the ROM data.
If another ROM with the same id already exists, undefined behavior will occur.